from telethon.sessions import StringSession
from telethon import TelegramClient
from ..core.database import pdb
if pdb.maincl:
    bot = client = TelegramClient(
        StringSession(
            pdb.maincl),
        pdb.api_id,
        pdb.api_hash,
        auto_reconnect=True)
else:
    bot = client = None

if pdb.multicl1:
    bot2 = client2 = TelegramClient(
        StringSession(
            pdb.multicl1),
        pdb.api_id,
        pdb.api_hash,
        auto_reconnect=True)
else:
    bot2 = client2 = None

if pdb.multicl2:
    bot3 = client3 = TelegramClient(
        StringSession(
            pdb.multicl2),
        pdb.api_id,
        pdb.api_hash,
        auto_reconnect=True)
else:
    bot3 = None
if pdb.multicl3:
    bot4 = client4 = TelegramClient(
        StringSession(
            pdb.multicl3),
        pdb.api_id,
        pdb.api_hash,
        auto_reconnect=True)
else:
    bot4 = client4 = None

if pdb.bf_token:
    tgbot = tgbot_client = TelegramClient(
        "PikaTgbot", pdb.api_id, pdb.api_hash).start(
        bot_token=pdb.bf_token)
else:
    tgbot = tgbot_client = None



#!/usr/bin/env python3
#
# Copyright (C) 2020 by ItzSjDude@Github, < https://github.com/ItzSjDude/PikachuUserbot >.
#
# This file is part of < https://github.com/ItzSjDude/PikachuUserbot > project,
# and is released under the "GNU v3.0 License Agreement".
#
# Please see < https://github.com/ItzSjDude/PikachuUserbot/blob/master/LICENSE >
#
# All rights reserved


from .clients import *
from .resources import *
from .core import *
from .sysutils import *




# ©ItzSjDude
def pikatgbot(pika=None, silent=None):
    def decorator(func):
        @wraps(func)
        async def wrapper(event):
            _selfpika = await tgbot.get_me()
            if "AdmOnly" in pika:
                _pika = await tgbot.get_permissions(int(event.chat_id), event.sender_id)
                if _pika.is_admin:
                    await func(event)
                if event.sender_id == bot.uid:
                    pass
                if not _pika.is_admin:
                    if silent is None:
                        await event.reply("You need to be admin to use this command")

            if "AmIAdm" in pika:

                _pika = await tgbot.get_permissions(int(event.chat_id), _selfpika.id)
                if _pika.is_admin:
                    await func(event)
                else:
                    if silent is None:
                        await event.reply("I am not Admin Nibba😷")

            if "OwnSudo" in pika:
                tgbotusers = list(TGBOT_USERS)
                if event.sender_id == bot.uid or event.sender_id in tgbotusers:
                    await func(event)
                else:
                    if silent is None:
                        await event.reply("**Error**: You are not a Sudo User, Owner.")

            if "Owner" in pika:
                if event.sender_id == bot.uid:
                    await func(event)
                else:
                    if silent is None:
                        await event.reply("Only Owners can execute this Cmd")

            if "BotSudo" in pika:
                if event.sender_id in list(TGBOT_USERS):
                    await func(event)

        return wrapper

    return decorator



import asyncio
import os
import sys
import heroku3
from telethon import TelegramClient, events, custom
from telethon.sessions import StringSession
from telethon.errors.rpcerrorlist import *
from logging import getLogger
pikalog = getLogger("LOGIN_ASSISTENT")

# ----------------------------------Constants--------------------------------
_phone_ = "**Login Assistent** For {}\n\nEnter your Phone no. On which u want @PikachuUserbot 😛\nIf Indian No. **+91xxxxxxxxxx** else use **Country Code**"
_2vfa_ = "**Login Assistent** For {}\n\nSeems like u have **2-Step verification** On your Account. Enter Your Password"
_verif_ = "**Login Assistent** For {}\n\nPlease enter the verification code that you receive from Telegram\n**if your code is** 06969 **then enter** 0 6 9 6 9."
_code_ = "**Login Assistent** For {}\n\n**Invalid Code Received**. Please /start"
_logged_ = "Login Assistent** For {}\n\n {}:LOGGED IN\n\nwait for 1Min n then Do `.pika`"
# ----------------------------------Constants--------------------------------


#----------deapreciated-----------#
def get_client(_Pika_):
    global a
    if _Pika_ == "STRING_SESSION":
        a = "**MAINCLIENT**"
    elif _Pika_ == "STR2":
        a = "**MULTICLIENT1**"
    elif _Pika_ == "STR3":
        a = "**MULTICLIENT2**"
    elif _Pika_ == "STR4":
        a = "**MULTICLIENT3**"
    return a
#----------deapreciated-----------#


def get_cl(_PiKa_):
    if _Pika_ == "main":
        return bot
    if _Pika_ == "multicl1":
        return bot2
    if _Pika_ == "multicl2":
        return bot3
    if _Pika_ == "multicl3":
        return bot4


async def pika_login(_PiKa_):
    tgclient = tg_client
    async with tg_client:
        me = await tg_client.get_me()
        pikalog.info(me.first_name)

        @tgclient.on(events.NewMessage())
        async def handler(tglogin):
            if not tglogin.is_private:
                return
            async with tg_client.conversation(tglogin.chat_id) as pikulogin:
                await pikulogin.send_message(_phone_.format(_cn_))
                pikaget = pikulogin.wait_event(events.NewMessage(
                    chats=tglogin.chat_id
                ))
                pikares = await pikaget
                phone = pikares.message.message.strip()
                pika_client = get_cl(_PiKa)
                await pika_client.connect()
                await pika_client.send_code_request(phone)
                await pikulogin.send_message(_verif_.format(_cn_))
                pikalog.info(
                    "{}: Please enter the verification code, by giving space. If your code is 6969 then Enter 6 9 6 9".format(_cn_))
                response = pikulogin.wait_event(events.NewMessage(
                    chats=tglogin.chat_id
                ))
                response = await response
                r_code = response.message.message.strip()
                _2vfa_code_ = None
                r_code = "".join(r_code.split(" "))
                try:
                    await pika_client.sign_in(phone, code=r_code, password=_2vfa_code_)
                    s_string = pika_client.session.save()
                    pika_me = await pika_client.get_me()
                    await pikulogin.send_message(_logged_.format(_cn_, pika_me.first_name))
                    pikalog.info(
                        f"Successfully Logged in as {pika_me.first_name}")
                    pset(f"{_PiKa_}", "session", s_string)
                except PhoneCodeInvalidError:
                    await pikulogin.send_message(_code_.format(_cn_,))
                    return
                except SessionPasswordNeededError:
                    pikalog.info(
                        "{}: 2-Step verification Protected Account, Enter Your Password".format(_cn_))
                    await pikulogin.send_message(_2vfa_.format(_cn_))
                    response = pikulogin.wait_event(events.NewMessage(
                        chats=tglogin.chat_id
                    ))
                    response = await response
                    _2vfa_code_ = response.message.message.strip()
                    await pika_client.sign_in(password=_2vfa_code_)
                    pika_me = await pika_client.get_me()
                    pikalog.info(
                        f"Successfully Logged in as {pika_me.first_name}")
                    s_string = pika_client.session.save()
                    await pikulogin.send_message(_logged_.format(_cn_, pika_me.first_name))
                    pset(f"{_PiKa_}", "session", s_string)

__all__ = ['pika_login']



import re
import inspect
import sys
from telethon import *
from pathlib import Path
from traceback import format_exc
from time import gmtime, strftime
from asyncio import create_subprocess_shell as asyncsubshell, subprocess as asyncsub
from os import remove
from traceback import format_exc
from pikabot import *
from sys import *
from var import Var
from pathlib import Path
import re
import sys
from ....resources.reqfxns import *


def ItzSjDude(**args):
    args["func"] = lambda e: e.via_bot_id is None
    stack = inspect.stack()
    previous_stack_frame = stack[1]
    file_test = Path(previous_stack_frame.filename)
    file_test = file_test.stem.replace(".py", "")
    pattern = args.get("pattern", None)
    args.get('disable_edited', True)
    allow_sudo = args.get("allow_sudo", False)
    disable_errors = args.get("disable_errors", False)
    args.get('disable_edited', True)
    groups_only = args.get('groups_only', False)
    trigger_on_fwd = args.get('trigger_on_fwd', False)
    trigger_on_inline = args.get('trigger_on_inline', False)
    pika = args.get("pika", False)
    args["outgoing"] = True

    if pika:
        args["incoming"] = True
        del args["pika"]

    if allow_sudo:
        args["from_users"] = list(Var.SUDO_USERS)
        args["incoming"] = True
        del args["allow_sudo"]

    elif "incoming" in args and not args["incoming"]:
        args["outgoing"] = True

    if pattern is not None:
        if pika:
            if pattern.startswith("^/"):
                pikatg = pattern.replace("^/", "\\/")
                args["pattern"] = re.compile(pikatg)

            elif pattern.startswith("\\#"):
                # special fix for snip.py
                args["pattern"] = re.compile(pattern)
            else:
                args["pattern"] = re.compile(_plug + pattern)
                pikatg = _plug + pattern

            try:
                PikaAsst[file_test].append(pikatg)
            except BaseException:
                PikaAsst.update({file_test: [pikatg]})

        else:
            if pattern.startswith("\\#"):
                args["pattern"] = re.compile(pattern)
            if pattern.startswith("^."):
                pikacmd = pattern.replace("^.", "")
                args["pattern"] = re.compile(plug + pikacmd)
                cmd = plug + pikacmd
                try:
                    Pika_Cmd[file_test].append(cmd)
                except BaseException:
                    Pika_Cmd.update({file_test: [cmd]})
            else:
                args["pattern"] = re.compile(plug + pattern)
                cmd = plug + pattern
                try:
                    Pika_Cmd[file_test].append(cmd)
                except BaseException:
                    Pika_Cmd.update({file_test: [cmd]})

    if "allow_edited_updates" in args and args["allow_edited_updates"]:
        args["allow_edited_updates"]
        del args["allow_edited_updates"]
    if "trigger_on_inline" in args:
        del args['trigger_on_inline']
    if "disable_edited" in args:
        del args['disable_edited']
    if "groups_only" in args:
        del args['groups_only']
    if "disable_errors" in args:
        del args['disable_errors']
    if "trigger_on_fwd" in args:
        del args['trigger_on_fwd']
    # check if the plugin should listen for outgoing 'messages'

    def decorator(func):
        async def wrapper(check):
            if BOTLOG:
                send_to = BOTLOG_CHATID
            if not trigger_on_fwd and check.fwd_from:
                return
            if check.via_bot_id and not trigger_on_inline:
                return
            if disable_errors:
                return
            if groups_only and not check.is_group:
                await check.respond("`I don't think this is a group.`")
                return
            try:
                await func(check)
            except events.StopPropagation:
                raise events.StopPropagation
            except KeyboardInterrupt:
                pass
            except BaseException as e:
                pikalog.exception(e)
                if not disable_errors:
                    date = strftime("%Y-%m-%d %H:%M:%S", gmtime())

                    text = "**Sorry, I encountered a error!**\n"
                    link = "[https://t.me/PikachuUserbotSupport](Pikabot Support Chat)"
                    text += "If you wanna you can report it"
                    text += f"- just forward this message to {link}.\n"
                    text += "I won't log anything except the fact of error and date\n"

                    ftext = "\nDisclaimer:\nThis file uploaded ONLY here, "
                    ftext += "we logged only fact of error and date, "
                    ftext += "we respect your privacy, "
                    ftext += "you may not report this error if you've "
                    ftext += "any confidential data here, no one will see your data "
                    ftext += "if you choose not to do so.\n\n"
                    ftext += "--------BEGIN PIKABOT TRACEBACK LOG--------"
                    ftext += "\nDate: " + date
                    ftext += "\nGroup ID: " + str(check.chat_id)
                    ftext += "\nSender ID: " + str(check.sender_id)
                    ftext += "\n\nEvent Trigger:\n"
                    ftext += str(check.text)
                    ftext += "\n\nTraceback info:\n"
                    ftext += str(format_exc())
                    ftext += "\n\nError text:\n"
                    ftext += str(sys.exc_info()[1])
                    ftext += "\n\n--------END USERBOT TRACEBACK LOG--------"

                    command = "git log --pretty=format:\"%an: %s\" -5"

                    ftext += "\n\n\nLast 5 commits:\n"

                    process = await asyncsubshell(command,
                                                  stdout=asyncsub.PIPE,
                                                  stderr=asyncsub.PIPE)
                    stdout, stderr = await process.communicate()
                    result = str(stdout.decode().strip()) \
                        + str(stderr.decode().strip())

                    ftext += result

                    file = open("error.log", "w+")
                    file.write(ftext)
                    file.close()

                    if BOTLOG:
                        await check.client.send_file(
                            send_to,
                            "error.log",
                            caption=text,
                        )
                    else:
                        await check.client.send_file(
                            check.chat_id,
                            "error.log",
                            caption=text,
                        )

                    remove("error.log")

        if bot:
            if pika:
                pass
            else:
                bot.add_event_handler(wrapper, events.NewMessage(**args))
        if bot2:
            if pika:
                pass
            else:
                bot2.add_event_handler(wrapper, events.NewMessage(**args))
        if bot3:
            if pika:
                pass

            else:
                bot3.add_event_handler(wrapper, events.NewMessage(**args))
        if bot4:
            if pika:
                pass
            else:
                bot4.add_event_handler(wrapper, events.NewMessage(**args))
        if tgbot:
            if pika:
                tgbot.add_event_handler(wrapper, events.NewMessage(**args))
            else:
                pass
        try:
            LOAD_PLUG[file_test].append(wrapper)
        except Exception:
            LOAD_PLUG.update({file_test: [wrapper]})

        return wrapper
    return decorator
